@@ -40,6 +40,7 @@ class Po2Md:
         self._disable_next_line = False
         self._disable = False
         self._enable_next_line = False
+        self.disabled_entries = []
 
         self.translations = None
         self.translations_with_msgctxt = None
@@ -184,8 +185,17 @@ class Po2Md:
             )
         else:
             translation = self._current_msgid
+            self.disabled_entries.append(
+                polib.POEntry(
+                    msgid=translation,
+                    msgstr='',
+                    msgctxt=self._current_msgctxt,
+                ),
+            )
+
         if not self._inside_codeblock:
             translation = self._escape_translation(translation)
+
         elif self._inside_indented_codeblock:
             # add 4 spaces before each line including next indented block code
             translation = '    %s' % re.sub('\n', '\n    ', translation)
@@ -193,10 +203,11 @@ class Po2Md:
             translation = '\n'.join(textwrap.wrap(translation, width=79))
         if self._inside_pblock:
             # wrap paragraphs fitting with markdownlint
-            lines = textwrap.wrap(translation, width=80)
             if self._codespan_inside_current_msgid:
                 # fix codespans wrapping
-                lines = fixwrap_codespans(lines)
+                lines = fixwrap_codespans(translation.split('\n'))
+            else:
+                lines = textwrap.wrap(translation, width=80)
             for line in lines:
                 self._current_line += '%s\n' % polib.unescape(line)
         else:
@@ -216,6 +227,7 @@ class Po2Md:
 
     def enter_block(self, block, details):
         # print('ENTER BLOCK', block.name, details)
+
         if self._inside_quoteblock and (
                 not self._current_line or self._current_line[0] != '>'
         ):
@@ -230,7 +242,8 @@ class Po2Md:
                 self._current_line += details['lang'][0][1]
             if 'fence_char' not in details:
                 self._inside_indented_codeblock = True
-            self._save_current_line()
+            if self._current_line:
+                self._save_current_line()
         elif block.value == md4c.BlockType.H:
             self._current_line += '%s ' % ('#' * details['level'])
         elif block.value == md4c.BlockType.LI:
@@ -430,6 +443,7 @@ class Po2Md:
 
     def text(self, block, text):
         # print("TEXT", "'%s'" % text)
+
         if not self._inside_htmlblock:
             if not self._inside_codeblock:
                 if self._inside_liblock and text == '\n':
